@@ -11,7 +11,7 @@ from urllib.error import URLError, HTTPError
 from socket import timeout
 import ssl
 
-from rkclient.auth import RK_USER_AUTH_HEADER
+from rkclient.auth import RK_USER_AUTH_HEADER, RK_PUC_AUTH_HEADER
 from rkclient.entities import PEM, Artifact
 from rkclient.serialization import PEMSerialization, _encode_as_base64
 
@@ -53,7 +53,8 @@ class RKClient:
                  emitter_id: Optional[UUID] = None,
                  timeout_sec: int = 5,
                  insecure: bool = True,
-                 user_auth: str = ''):
+                 user_auth: str = '',
+                 puc_auth: str = ''):
         """
 
         :param receiver_url:
@@ -67,9 +68,12 @@ class RKClient:
         self.emitter_id = emitter_id
         self.timeout_sec = timeout_sec
         self.user_auth = user_auth
+        self.puc_auth = puc_auth
         log.info(f"ver {RK_VERSION}, connecting to: {self.receiver_url}")
         if self.user_auth:
             log.info(f"Authorizing with {RK_USER_AUTH_HEADER} header")
+        elif self.puc_auth:
+            log.info(f"Authorizing with {RK_PUC_AUTH_HEADER} header")
         self.insecure = insecure
         if self.insecure:
             log.warning("Disabled SSL certificate check")
@@ -195,6 +199,8 @@ class RKClient:
         req = urllib.request.Request(url=url)
         if self.user_auth:
             req.add_header(RK_USER_AUTH_HEADER, self.user_auth)
+        elif self.puc_auth:
+            req.add_header(RK_PUC_AUTH_HEADER, self.puc_auth)
         return self._make_request(req)
 
     def _post(self, url_postfix: str, payload: str, query_params: Optional[Dict[str, Any]] = None) -> Tuple[str, bool]:
@@ -203,6 +209,8 @@ class RKClient:
         req.add_header('Content-Type', 'application/json')
         if self.user_auth:
             req.add_header(RK_USER_AUTH_HEADER, self.user_auth)
+        elif self.puc_auth:
+            req.add_header(RK_PUC_AUTH_HEADER, self.puc_auth)
         return self._make_request(req)
 
     def _make_request(self, request):
